@@ -102,9 +102,9 @@ def dbinfo(connection, database='', deltat=300):
 
     By default, the statistics are for a sampling interval of 5
     minutes.  You can request another sampling interval, up to an
-    hour, by passing a sampling interval in seconds after the database name.    
+    hour, by passing a sampling interval in seconds after the database name.
     """
-    
+
     if database == '-':
         database = ''
     db = zope.component.getUtility(ZODB.interfaces.IDatabase, database)
@@ -145,7 +145,7 @@ def zeocache(connection, database=''):
     By default, data for the main database are returned.  To return
     information for another database, pass the database name.
     """
-    
+
     db = zope.component.getUtility(ZODB.interfaces.IDatabase, database)
     print >> connection, ' '.join(map(str, db._storage._cache.fc.getStats()))
 
@@ -157,7 +157,7 @@ def zeostatus(connection, database=''):
     By default, data for the main database are returned.  To return
     information for another database, pass the database name.
     """
-    
+
     db = zope.component.getUtility(ZODB.interfaces.IDatabase, database)
     print >> connection, db._storage.is_connected()
 
@@ -171,8 +171,32 @@ def initialize(opened_event):
         if db.getActivityMonitor() is None:
             db.setActivityMonitor(ZODB.ActivityMonitor.ActivityMonitor())
 
-    port = int(config['port'])
-    zc.monitor.start(int(config['port']))
+    try:
+        #being backwards compatible here and not passing address if not given
+        port = int(config['port'])
+        zc.monitor.start(port)
+    except KeyError:
+        #new style bind
+        try:
+            bind = config['bind']
+            bind = bind.strip()
+            m = re.match(r'^(?P<addr>\S+):(?P<port>\d+)$', bind)
+            if m:
+                #we have an address:port
+                zc.monitor.start((m.group('addr'), int(m.group('port'))))
+                return
+
+            m = re.match(r'^(?P<port>\d+)$', bind)
+            if m:
+                #we have a port
+                zc.monitor.start(int(m.group('port')))
+                return
+
+            #we'll consider everything else as a domain socket
+            zc.monitor.start(bind)
+        except KeyError:
+            #no bind config no server
+            pass
 
 @zope.component.adapter(
     zope.traversing.interfaces.IContainmentRoot,
@@ -202,4 +226,3 @@ def getStatus(want=('VmSize', 'VmRSS')):
     for line in open('/proc/%s/status' % pid):
         if (line.split(':')[0] in want):
             yield line.strip()
-
